# Generated by Django 2.2.5 on 2019-09-02 22:35

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0041_messages_guid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='state',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='tracker.Messages_state'),
        ),
    ]



from isc_common.auth.models.user import User
from isc_common.auth.models.user_permission import User_permission
from isc_common.auth.models.usergroup import UserGroup
from isc_common.auth.models.usergroup_permission import Usergroup_permission
from isc_common.auth.models.widgets_trees import Widgets_trees
from isc_common.http.DSRequest import DSRequest
from isc_common.http.RPCResponse import RPCResponseConstant


class PermissionRequest(DSRequest):
    def __init__(self, request):
        DSRequest.__init__(self, request)
        data = self.get_data()
        table = data.get('table', None)
        id = data.get('id', None)
        id_widget = data.get('id_widget', None)

        if table:
            if id is not None and id_widget:
                structure = dict()
                if table == 'widgets_trees':
                    structure = Widgets_trees.objects.get_or_create(id_widget=id_widget)[0].structure

                if table == 'user':
                    user = User.objects.get(id=id)
                    widget = Widgets_trees.objects.get_or_create(id_widget=id_widget)[0]
                    structure = User_permission.objects.get_or_create(user=user, widget=widget)[0].permission

                if table == 'user_group':
                    usergroup = UserGroup.objects.get(id=id)
                    widget = Widgets_trees.objects.get_or_create(id_widget=id_widget)[0]
                    structure = Usergroup_permission.objects.get_or_create(usergroup=usergroup, widget=widget)[0].permission

                self.response = dict(response=dict(status=RPCResponseConstant.statusSuccess), data=structure)
        else:
            raise Exception(f"Check table: {table},  id: {id}")



import logging
import re

from django.db import connection

from isc_common.number import ToStr

logger = logging.getLogger(__name__)


def uncapitalize(str):
    return str[0:1].lower() + str[1:]


def dbl_qutes_str(str):
    return f'"{str}"'


def qutes_str(str):
    return f"'{str}'"


def delete_dbl_spaces(value):
    if value is None:
        return value

    if not isinstance(value, str):
        return ToStr(value)

    value = value.replace('\\n', ' ')
    return re.sub('\s+', ' ', value).strip()


def null2blanck(str):
    return '' if str == 'null' else str


def ExecuteStoredProc(storedProcName, parametrs):
    c = connection.cursor()
    try:
        # c.execute("BEGIN")
        res = c.callproc(storedProcName, parametrs)
        results, = c.fetchone()
        # c.execute("COMMIT")
        return results
    except Exception as ex:
        logger.error(ex)
        raise ex
    finally:
        c.close()


def ExecuteStoredProcRows(storedProcName, parametrs):
    c = connection.cursor()
    try:
        # c.execute("BEGIN")
        res = c.callproc(storedProcName, parametrs)
        results = c.fetchall()
        # c.execute("COMMIT")
        return results
    except Exception as ex:
        logger.error(ex)
        raise ex
    finally:
        c.close()


class Common:
    @classmethod
    def get_size_file_str(cls, value):
        if value == 0:
            return ""

        if value > 0 and value <= 1024:
            return f'{value} Байт'

        if value > 1024 and value <= 1024 * 1024:
            return f'{round(value / 1024, 2)} КБайт'

        if value > 1024 * 1024 and value <= 1024 * 1024 * 1024:
            return f'{round(value / 1024 / 1024, 2)} МБайт'

        if value > 1024 * 1024 * 1024:
            return f'{round(value / 1024 / 1024 / 1024, 2)}  ГБайт'
        return value

    @classmethod
    def arraund_error(error):
        str = '!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
        return f'\n{str}\n{error}\n{str}'



import logging

from isc_common.fields.code_field import JSONFieldIVC
from isc_common.fields.related import ForeignKeyCascade
from isc_common.models.audit import AuditModel

logger = logging.getLogger(__name__)


class User_permission(AuditModel):
    user = ForeignKeyCascade("User")
    widget = ForeignKeyCascade("Widgets_trees")
    permission = JSONFieldIVC()

    def __str__(self):
        return f"{self.user.username}: {self.widget.id_widget}"

    class Meta:
        verbose_name = 'Доступы для пользователей'
        unique_together = (("user", "widget"),)




import configparser
import logging
import os
from datetime import datetime
from os.path import getmtime
from tkinter import *
from tkinter import filedialog
from uuid import UUID
from xml.dom.minidom import parseString

from django.core.management import BaseCommand
from django.db import transaction
from lxml import etree
from tqdm import tqdm

from isc_common import setAttr, str_to_bool
from one_c.models.document_1c import Document_1c
from one_c.models.documents_param_1c import Documents_param_1c
from one_c.models.documents_param_cross_1c import Documents_param_cross_1c
from one_c.models.entity_1c import Entity_1c
from one_c.models.files_1c import Files_1c
from one_c.models.param_type import Param_type

logger = logging.getLogger(__name__)


class V8Exch:
    def __init__(self, pbar, filename):
        self.filename = filename
        self.pbar = pbar
        self.started = False
        self.entities = dict()
        self.attributes = dict()
        self.step = 0
        self.tags = 0

    def start(self, tag, attrib):
        if not self.started:
            m = re.search('({.*})', tag)
            if m:
                ns = m.group(1)
                tag = tag.replace(ns, '')
                if tag == 'Data':
                    self.started = True
        else:
            index = tag.find('CatalogObject.')
            if index == -1:
                self.tag = tag
                self.param_type = self.attributes.get(tag)
                if self.param_type is None:
                    self.param_type, created = Param_type.objects.get_or_create(code=tag)
                    setAttr(self.attributes, tag, self.param_type)
            else:
                tag = tag.replace('CatalogObject.', '')
                self.tag = tag
                self.entity = self.entities.get(tag)
                if self.entity is None:
                    self.entity, created = Entity_1c.objects.get_or_create(code=tag)
                    setAttr(self.entities, tag, self.entity)

                self.step += 1
                # logger.debug(f'step: {self.step}, tags: {self.tags}')

            # logger.debug(f'tag: {tag}')

    def end(self, tag):
        self.tags += 1

    def data(self, data):
        if data.strip() != '':
            # logger.debug(f'tag: {self.tag}, data: {data}')
            if self.tag == 'Ref':
                self.document, created = Document_1c.objects.get_or_create(entity=self.entity, ref=UUID(data.strip()))
                if not created:
                    for documents_param_cross_1c in Documents_param_cross_1c.objects.filter(document=self.document):
                        try:
                            Documents_param_1c.objects.filter(id=documents_param_cross_1c.param).delete()
                            documents_param_cross_1c.delete()
                            documents_param_cross_1c.save()
                        except Exception as ex:
                            logger.error(ex)

                param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value_uuid=UUID(data.strip()))
                Documents_param_cross_1c.objects.create(document=self.document, param=param)

                if self.pbar:
                    self.pbar.update(1)
            else:
                try:
                    param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value_uuid=UUID(data.strip()))

                except ValueError:
                    try:
                        param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value_boolean=str_to_bool(data.strip()))
                    except ValueError:
                        try:
                            param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value_int=int(data.strip()))
                        except ValueError:
                            try:
                                param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value_float=float(data.strip()))
                                if created:
                                    logger.debug(f'Created: {param}')
                            except ValueError:
                                param, created = Documents_param_1c.objects.get_or_create(type=self.param_type, value=data.strip())

                Documents_param_cross_1c.objects.create(document=self.document, param=param)

                # logger.debug(f'rec document_param: {document_param}')

    def close(self):
        if self.pbar:
            self.pbar.close()


class Command(BaseCommand):
    config = configparser.ConfigParser()
    config['DEFAULT'] = {}

    config.sections()
    config.read('config.ini')

    help = "Загрузка документов из 1С"
    root = Tk()

    def handle(self, *args, **options):

        try:
            try:
                initialdir = self.config['DEFAULT']['1cdir']
                if not os.path.exists(initialdir):
                    initialdir = None
            except KeyError:
                initialdir = None

            self.root.filename = filedialog.askopenfilename(title="Выбирите файл документов", initialdir=initialdir)
            dir, _ = os.path.split(self.root.filename)
            self.config['DEFAULT']['1cdir'] = dir
            logger.debug(f'filename : {self.root.filename}')
            self.root.withdraw()

            date_modification = datetime.fromtimestamp(getmtime(self.root.filename))
            with transaction.atomic():
                file, created = Files_1c.objects.get_or_create(real_name=self.root.filename, file_modification_time=date_modification, props=Files_1c.props.imp)

                if created:
                    file = open(self.root.filename, 'r')
                    data = file.read()
                    file.close()
                    dom = parseString(data)
                    qty = len(dom.getElementsByTagName('Ref'))

                    pbar = tqdm(total=qty)

                    # with transaction.atomic():
                    parser = etree.XMLParser(target=V8Exch(pbar, self.root.filename))
                    etree.parse(self.root.filename, parser)
                else:
                    logger.warning(f'Файл: {self.root.filename}, уже импортирован !')

                with open('config.ini', 'w') as configfile:
                    self.config.write(configfile)
        except Exception as ex:
            self.root.withdraw()
            raise ex



from django.urls import path

from files_blk.views import files

urlpatterns = [

    path('Files/Fetch/', files.Files_Fetch),
    path('Files/Add', files.Files_Add),
    path('Files/Update', files.Files_Update),
    path('Files/Remove', files.Files_Remove),
    path('Files/Lookup/', files.Files_Lookup),
    path('Files/Info/', files.Files_Info),
    path('Files/Copy', files.Files_Copy),

]



import logging

from django.core.management import BaseCommand
from django.db import connections

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    def dbl_qutes_str(self, str):
        return f'"{str}"'

    def add_arguments(self, parser):
        parser.add_argument('--name', type=str)
        parser.add_argument('--connection', type=str)

    def handle(self, *args, **options):
        if options['name']:
            self.name = options['name']
        else:
            raise Exception(f'name param not exists')

        if options['connection']:
            self.connection = options['connection']
        else:
            raise Exception(f'connection param not exists')

        with connections[self.connection].cursor() as cursor:
            try:
                cursor.execute(f'DROP DATABASE IF EXISTS {self.name}')

            except Exception as e:
                logger.error(e)



import logging

from django.db.models import UUIDField, Model

from isc_common.fields.related import ForeignKeyProtect
from one_c.models.entity_1c import Entity_1c

logger = logging.getLogger(__name__)


class Document_1c(Model):
    entity = ForeignKeyProtect(Entity_1c)
    ref = UUIDField(primary_key=True)

    def __str__(self):
        return f"(ref: {self.ref}, entity: {self.entity})"

    class Meta:
        verbose_name = 'Документ'



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from isc_common.models.progresses import Progresses, ProgressesManager


@JsonResponseWithException()
def Progresses_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Progresses.objects.
                filter().
                get_range_rows1(
                request=request,
                function=ProgressesManager.getRecord
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Add(request):
    return JsonResponse(DSResponseAdd(data=Progresses.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Update(request):
    return JsonResponse(DSResponseUpdate(data=Progresses.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Progresses.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Progresses.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Info(request):
    return JsonResponse(DSResponse(request=request, data=Progresses.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Progresses_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Progresses.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)

@JsonResponseWithException()
def Progresses_Resore(request):
    return JsonResponse(DSResponse(request=request, data=Progresses.objects.resoreFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)



from django.urls import path

from events.views import event_type_users

urlpatterns = [

    path('Event_type_users/Fetch/', event_type_users.Event_type_users_Fetch),
    path('Event_type_users/Add', event_type_users.Event_type_users_Add),
    path('Event_type_users/Update', event_type_users.Event_type_users_Update),
    path('Event_type_users/Remove', event_type_users.Event_type_users_Remove),
    path('Event_type_users/Lookup/', event_type_users.Event_type_users_Lookup),
    path('Event_type_users/Info/', event_type_users.Event_type_users_Info),
    path('Event_type_users/Copy', event_type_users.Event_type_users_Copy),

]



# Generated by Django 2.2.4 on 2019-08-25 21:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0065_auto_20190825_2037'),
    ]

    operations = [
        migrations.AddField(
            model_name='day_types',
            name='isholiday',
            field=models.BooleanField(default=False),
        ),
    ]



import logging

from django.db.models import Model
from transliterate import translit
from transliterate.exceptions import LanguageDetectionError

from isc_common.fields.code_field import CodeField

logger = logging.getLogger(__name__)


class Entity_1c(Model):
    code = CodeField(unique=True)

    @property
    def translited_code(self):
        try:
            return translit(self.code, reversed=True).replace("'", '').replace("'", '')
        except LanguageDetectionError:
            return self.code

    def __str__(self):
        return f"(id: {self.id}, code: {self.code})"

    class Meta:
        verbose_name = 'Сущность 1С'



from django.core.files.storage import DefaultStorage
from django.db.models import FileField
from isc_common.fields import Field


class DbFileField(FileField, Field):
    def __init__(self, verbose_name=None, name=None, upload_to='', storage=None, **kwargs):
        def_str = '/blob/filename/mimetype'
        _upload_to = f"{upload_to}{def_str}" if upload_to.find(def_str) == -1 else upload_to
        if not storage:
            storage = DefaultStorage()
            storage.download_from = _upload_to
        super().__init__(verbose_name=verbose_name, name=name, upload_to=_upload_to, storage=storage, **kwargs)



# Generated by Django 2.2.1 on 2019-05-16 06:48

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0019_messages_view'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages',
            name='checksum',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, verbose_name='Checksum MD5'),
        ),
    ]



import logging

from django.contrib.postgres.fields import ArrayField
from django.db.models import BooleanField, BigIntegerField

from isc_common.auth.models.user import User
from isc_common.fields.related import ForeignKeyCascade
from isc_common.http.DSRequest import DSRequest
from isc_common.managers.common_tree_grid_manager import CommonTreeGridManager
from isc_common.models.audit import AuditQuerySet
from isc_common.models.base_ref import BaseRefHierarcy

logger = logging.getLogger(__name__)


class Messages_theme_viewQuerySet(AuditQuerySet):
    def get_range_rows1(self, request, function):
        request = DSRequest(request=request)
        criteria = request.get_criteria()
        if isinstance(criteria, list):
            criteria = [l for l in request.get_criteria() if l.get('fieldName') != 'user_id']
        request.set_criteria(criteria=criteria)
        self.alive_only = request.alive_only
        self.enabledAll = request.enabledAll
        return self.get_range_rows(start=request.startRow, end=request.endRow, function=function, json=request.json)


class Messages_theme_view_Manager(CommonTreeGridManager):
    @classmethod
    def getRecord(cls, record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            # 'full_name': record.full_name,
            'description': record.description,
            'parent_id': record.parent_id,
            'lastmodified': record.lastmodified,
            'isFolder': record.isFolder,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return Messages_theme_viewQuerySet(self.model, using=self._db)


class Messages_theme_view(BaseRefHierarcy):
    users = ArrayField(BigIntegerField(), default=list)
    creator = ForeignKeyCascade(User, null=True, blank=True, related_name='creator_theme')
    isFolder = BooleanField(default=False)

    def __str__(self):
        return f'{self.code}: {self.name}'

    objects = Messages_theme_view_Manager()

    class Meta:
        verbose_name = 'Темы задач'
        managed = False
        db_table = 'tracker_messages_theme_view'



import os

from PIL import Image
from django.db.models.fields.files import ImageField, ImageFieldFile
from isc_common.fields import Field


class ThumbnailImageFieldFile(ImageFieldFile, Field):
    def _add_thumb(self, s):
        """
        Modifies a string (filename, URL) containing an image filename, to insert
        '.thumb'
        """
        parts = s.split(".")
        parts.insert(-1, "thumb")
        if parts[-1].lower() not in ['jpeg', 'jpg']:
            parts[-1] = 'jpg'
        return ".".join(parts)

    def _get_thumb_path(self):
        return self._add_thumb(self.path)

    thumb_path = property(_get_thumb_path)

    def _get_thumb_url(self):
        return self._add_thumb(self.url)

    thumb_url = property(_get_thumb_url)

    def save(self, name, content, save=True):
        super().save(name, content, save)
        img = Image.open(self.path)
        img.thumbnail((self.field.thumb_width, self.field.thumb_height), Image.ANTIALIAS)
        img.save(self.thumb_path, 'JPEG')

    def delete(self, save=True):
        if os.path.exists(self.thumb_path):
            os.remove(self.thumb_path)
        super().delete()(save)


class ThumbnailImageField(ImageField):
    """
    Behaves like a regular ImageField, but stores an extra (JPEG) thumbnail
    image, providing FIELD.thumb_url and FIELD.thumb_path.

    Accepts two additional, optional arguments: thumb_width and thumb_height,
    both defaulting to 128 (pixels). Resizing will preserve aspect ratio while
    staying inside the requested dimensions; see PIL's Image.thumbnail()
    method documentation for details.
    """
    attr_class = ThumbnailImageFieldFile

    def __init__(self, thumb_width=128, thumb_height=128, *args, **kwargs):
        self.thumb_width = thumb_width
        self.thumb_height = thumb_height
        super().__init__(*args, **kwargs)



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from twits.models.chat_users import Chat_users
from twits.models.chat_users_view import Chat_usersView, Chat_usersViewManager


@JsonResponseWithException()
def Chat_users_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Chat_usersView.objects.
                filter().
                get_range_rows1(
                request=request,
                function=Chat_usersViewManager.getRecord
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Add(request):
    return JsonResponse(DSResponseAdd(data=Chat_users.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Update(request):
    return JsonResponse(DSResponseUpdate(data=Chat_users.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Chat_users.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Chat_users.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Info(request):
    return JsonResponse(DSResponse(request=request, data=Chat_users.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Chat_users_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Chat_users.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)



# Generated by Django 2.2.5 on 2019-09-08 15:34

import bitfield.models
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('twits', '0009_auto_20190905_1810'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='chat_user_user',
            options={'verbose_name': 'Чаты личной переписки'},
        ),
        migrations.AlterModelOptions(
            name='chats',
            options={'verbose_name': 'Групповые чаты'},
        ),
        migrations.AddField(
            model_name='chat_user_user',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'),), db_index=True, default=0),
        ),
        migrations.AddField(
            model_name='chats',
            name='props',
            field=bitfield.models.BitField((('compulsory_reading', 'Обязательное прочтение'),), db_index=True, default=0),
        ),
    ]



from django.urls import path

from twits.views import chat_users

urlpatterns = [

    path('Chat_users/Fetch/', chat_users.Chat_users_Fetch),
    path('Chat_users/Add', chat_users.Chat_users_Add),
    path('Chat_users/Update', chat_users.Chat_users_Update),
    path('Chat_users/Remove', chat_users.Chat_users_Remove),
    path('Chat_users/Lookup/', chat_users.Chat_users_Lookup),
    path('Chat_users/Info/', chat_users.Chat_users_Info),
    path('Chat_users/Copy', chat_users.Chat_users_Copy),

]



from django.urls import path

from tracker.views import messages_theme

urlpatterns = [

    path('Messages_theme/Fetch/', messages_theme.Messages_theme_Fetch),
    path('Messages_theme/FetchAdmin/', messages_theme.Messages_theme_FetchAdmin),
    path('Messages_theme/Add', messages_theme.Messages_theme_Add),
    path('Messages_theme/Update', messages_theme.Messages_theme_Update),
    path('Messages_theme/Remove', messages_theme.Messages_theme_Remove),
    path('Messages_theme/Lookup/', messages_theme.Messages_theme_Lookup),
    path('Messages_theme/Info/', messages_theme.Messages_theme_Info),

]



from django.urls import path

from isc_common.auth.views import user_permission

urlpatterns = [

    path('UserPermission/Fetch/', user_permission.User_permission_Fetch),
    path('UserPermission/Add', user_permission.User_permission_Add),
    path('UserPermission/Update', user_permission.User_permission_Update),
    path('UserPermission/Remove', user_permission.User_permission_Remove),
    path('UserPermission/Lookup', user_permission.User_permission_Lookup),

]



import logging

from isc_common.fields.code_field import JSONFieldIVC
from isc_common.fields.related import ForeignKeyCascade
from isc_common.models.audit import AuditModel

logger = logging.getLogger(__name__)


class Usergroup_permission(AuditModel):

    usergroup = ForeignKeyCascade("UserGroup")
    widget = ForeignKeyCascade("Widgets_trees")
    permission = JSONFieldIVC()

    # def __str__(self):
    #     return f"{self.code}: {self.name}"

    class Meta:
        verbose_name = 'Доступы для групп'
        unique_together = (("usergroup", "widget"),)



from django.urls import path
from files_blk.views import files_group

urlpatterns = [

    path('Files_group/Fetch/', files_group.Files_group_Fetch),
    path('Files_group/Add', files_group.Files_group_Add),
    path('Files_group/Update', files_group.Files_group_Update),
    path('Files_group/Remove', files_group.Files_group_Remove),
    path('Files_group/Lookup/', files_group.Files_group_Lookup),
    path('Files_group/Info/', files_group.Files_group_Info),
    path('Files_group/Copy', files_group.Files_group_Copy),

]



import logging

from django.core.management import BaseCommand

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Тестирование"

    def handle(self, *args, **options):
        ...



import logging

from crypto.models.crypto_file import Crypto_file, CryptoManager, CryptoQuerySet
from isc_common.fields.related import ForeignKeyCascade
from tracker.models.messages import Messages

logger = logging.getLogger(__name__)


class Messages_filesQuerySet(CryptoQuerySet):
    def filter(self, *args, **kwargs):
        return super().filter(*args, **kwargs)


class Messages_filesManager(CryptoManager):

    @classmethod
    def getRecord(cls, record):
        res = {
            'id': record.id,
            'format': record.format,
            'mime_type': record.mime_type,
            'size': record.size if not str(record.size).startswith('.') else str(record.size).replace('.', '0.'),
            'real_name': record.real_name,
        }
        return res

    def get_queryset(self):
        return Messages_filesQuerySet(self.model, using=self._db)


class Messages_files(Crypto_file):
    objects = Messages_filesManager()

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Файлы'



from isc_common.auth.models.user import User
from isc_common.http.DSRequest import DSRequest
from isc_common.http.RPCResponse import RPCResponseConstant


class ChangePassRequest(DSRequest):
    def __init__(self, request):
        DSRequest.__init__(self, request)
        data = self.get_data()

        try:
            user = User.objects.get(pk=data.get('userId', None))
            if user.check_password(data.get('oldPassword', None)):
                user.set_password(data.get('password', None))
                self.response = dict(status=RPCResponseConstant.statusSuccess)
            else:
                self.response = dict(status=RPCResponseConstant.statusValidationError, errorMessage="Пароль не изменен, проверьте вводимые параметры.")

        except Exception as ex:
            self.response = dict(status=RPCResponseConstant.statusFailure, errorMessage=str(ex))



from django.urls import path

from one_c.views import document_1c

urlpatterns = [

    path('Document_1c/Fetch/', document_1c.Document_1c_Fetch),
    path('Document_1c/Add', document_1c.Document_1c_Add),
    path('Document_1c/Update', document_1c.Document_1c_Update),
    path('Document_1c/Remove', document_1c.Document_1c_Remove),
    path('Document_1c/Lookup/', document_1c.Document_1c_Lookup),
    path('Document_1c/Info/', document_1c.Document_1c_Info),

]



# Generated by Django 2.2.6 on 2019-10-09 14:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0066_auto_20190920_1118'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='messages',
            unique_together=set(),
        ),
    ]



# Generated by Django 2.2.4 on 2019-08-26 06:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('clndr', '0066_day_types_isholiday'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shift_day_relax',
            options={'ordering': ['relaxorder', 'shiftday'], 'verbose_name': 'Запланированные перекуры и отдыхи'},
        ),
        migrations.AddField(
            model_name='shift_day_relax',
            name='relaxorder',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
        migrations.AlterUniqueTogether(
            name='shift_day_relax',
            unique_together={('relaxorder', 'shiftday')},
        ),
    ]



# Generated by Django 2.2.5 on 2019-09-20 11:18

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('tracker', '0065_auto_20190916_1759'),
    ]

    operations = [
        migrations.AlterField(
            model_name='messages_theme',
            name='code',
            field=isc_common.fields.code_field.CodeField(blank=True, null=True, unique=True),
        ),
    ]



import logging

from django.core.management import BaseCommand

from isc_common.auth.models.user import User
from isc_common.common.mat_views import refresh_mat_view

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument('--username', type=str)
        # parser.add_argument('--message', type=str)

    def handle(self, *args, **options):
        username = options.get('username')
        user = User.objects.get(username=username)
        # message = options.get('message')

        refresh_mat_view('kd_documents_mview', username)
        print("Done.")

        refresh_mat_view('kd_documents_mview', username)
        print("Done.")



# Generated by Django 3.0.3 on 2020-02-08 11:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('history', '0012_auto_20191116_1827'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='visitor',
            constraint=models.UniqueConstraint(fields=('username', 'ip_address'), name='Visitor_unique_1'),
        ),
        migrations.AddConstraint(
            model_name='visitor',
            constraint=models.UniqueConstraint(condition=models.Q(username=None), fields=('ip_address',), name='Visitor_unique_2'),
        ),
    ]



import logging

from bitfield import BitField

from isc_common.bit import IsBitOn
from isc_common.models.base_ref import BaseRef, BaseRefQuerySet, StatusBaseRefManager

logger = logging.getLogger(__name__)


class Messages_stateQuerySet(BaseRefQuerySet):
    pass

class Messages_stateManager(StatusBaseRefManager):

    @classmethod
    def getRecord(cls, record):
        res = {
            'id': record.id,
            'code': record.code,
            'name': record.name,
            'description': record.description,
            'props': record.props._value,
            'disabled': IsBitOn(record.props, 0),
        }
        return res

    def get_queryset(self):
        return Messages_stateQuerySet(self.model, using=self._db)


class Messages_state(BaseRef):
    props = BitField(flags=(
        ('disabled', 'Неактивная запись в гриде')
    ), default=0, db_index=True)

    objects = Messages_stateManager()

    def __str__(self):
        return f"id: {self.code}, id: {self.code}, name: {self.name}, description: {self.description}"

    class Meta:
        verbose_name = 'Состояние задачи'

    @classmethod
    def message_state_new(cls):
        return Messages_state.objects.update_or_create(code="new", defaults=dict(name='Новый'))[0]

    @classmethod
    def message_state_closed(cls):
        return Messages_state.objects.update_or_create(code="closed", defaults=dict(name='Закрыто'))[0]

    @classmethod
    def message_state_delivered(cls):
        return Messages_state.objects.update_or_create(code="delivered", defaults=dict(name='Доставлено'))[0]

    @classmethod
    def message_state_readed(cls):
        return Messages_state.objects.update_or_create(code="readed", defaults=dict(name='Прочитано'))[0]

    @classmethod
    def message_state_not_readed(cls):
        return Messages_state.objects.get_or_create(code="delivered_not_readed", defaults=dict(name='Доставлено (Не прочитано)'))[0]
